@@ -7,13 +7,19 @@ Describe
 '''
 import errno
 import logging
-from pyroute2.netlink import CTRL_CMD_GETFAMILY
-from pyroute2.netlink import GENL_ID_CTRL
-from pyroute2.netlink import NLM_F_REQUEST
-from pyroute2.netlink import SOL_NETLINK
-from pyroute2.netlink import NETLINK_ADD_MEMBERSHIP
-from pyroute2.netlink import NETLINK_DROP_MEMBERSHIP
-from pyroute2.netlink import ctrlmsg
+
+from pyroute2.netlink import (
+    CTRL_CMD_GETFAMILY,
+    CTRL_CMD_GETPOLICY,
+    GENL_ID_CTRL,
+    NETLINK_ADD_MEMBERSHIP,
+    NETLINK_DROP_MEMBERSHIP,
+    NLM_F_ACK,
+    NLM_F_DUMP,
+    NLM_F_REQUEST,
+    SOL_NETLINK,
+    ctrlmsg,
+)
 from pyroute2.netlink.nlsocket import NetlinkSocket
 
 
@@ -27,6 +33,17 @@ class GenericNetlinkSocket(NetlinkSocket):
     mcast_groups = {}
     module_err_message = None
     module_err_level = 'error'
+    _prid = None
+
+    @property
+    def prid(self):
+        if self._prid is None:
+            raise RuntimeError(
+                'generic netlink protocol id is not obtained'
+                ' yet, run bind() before placing any requests'
+            )
+        else:
+            return self._prid
 
     def bind(self, proto, msg_class, groups=0, pid=None, **kwarg):
         '''
@@ -38,22 +55,27 @@ class GenericNetlinkSocket(NetlinkSocket):
         NetlinkSocket.bind(self, groups, pid, **kwarg)
         self.marshal.msg_map[GENL_ID_CTRL] = ctrlmsg
         msg = self.discovery(proto)
-        self.prid = msg.get_attr('CTRL_ATTR_FAMILY_ID')
-        self.mcast_groups = \
-            dict([(x.get_attr('CTRL_ATTR_MCAST_GRP_NAME'),
-                   x.get_attr('CTRL_ATTR_MCAST_GRP_ID')) for x
-                  in msg.get_attr('CTRL_ATTR_MCAST_GROUPS', [])])
+        self._prid = msg.get_attr('CTRL_ATTR_FAMILY_ID')
+        self.mcast_groups = dict(
+            [
+                (
+                    x.get_attr('CTRL_ATTR_MCAST_GRP_NAME'),
+                    x.get_attr('CTRL_ATTR_MCAST_GRP_ID'),
+                )
+                for x in msg.get_attr('CTRL_ATTR_MCAST_GROUPS', [])
+            ]
+        )
         self.marshal.msg_map[self.prid] = msg_class
 
     def add_membership(self, group):
-        self.setsockopt(SOL_NETLINK,
-                        NETLINK_ADD_MEMBERSHIP,
-                        self.mcast_groups[group])
+        self.setsockopt(
+            SOL_NETLINK, NETLINK_ADD_MEMBERSHIP, self.mcast_groups[group]
+        )
 
     def drop_membership(self, group):
-        self.setsockopt(SOL_NETLINK,
-                        NETLINK_DROP_MEMBERSHIP,
-                        self.mcast_groups[group])
+        self.setsockopt(
+            SOL_NETLINK, NETLINK_DROP_MEMBERSHIP, self.mcast_groups[group]
+        )
 
     def discovery(self, proto):
         '''
@@ -81,3 +103,24 @@ class GenericNetlinkSocket(NetlinkSocket):
                     logger(self.module_err_message)
             raise err
         return msg
+
+    def policy(self, proto):
+        '''
+        Extract policy information for a generic netlink protocol -- takes
+        a string as the only parameter, return protocol policy
+        '''
+        self.marshal.msg_map[GENL_ID_CTRL] = ctrlmsg
+        msg = ctrlmsg()
+        msg['cmd'] = CTRL_CMD_GETPOLICY
+        msg['attrs'].append(['CTRL_ATTR_FAMILY_NAME', proto])
+        return self.nlm_request(
+            msg,
+            msg_type=GENL_ID_CTRL,
+            msg_flags=NLM_F_REQUEST | NLM_F_DUMP | NLM_F_ACK,
+        )
+
+    def get(self, *argv, **kwarg):
+        return tuple(super().get(*argv, **kwarg))
+
+    def nlm_request(self, *argv, **kwarg):
+        return tuple(super().nlm_request(*argv, **kwarg))
