@@ -1,16 +1,14 @@
 import errno
+
 from pyroute2 import netns
-from pyroute2 import Inotify
-from pyroute2 import IPRoute
-from pyroute2.netlink.rtnl import RTM_NEWNETNS
-from pyroute2.netlink.rtnl import RTM_DELNETNS
+from pyroute2.inotify.inotify_fd import Inotify
+from pyroute2.iproute.linux import IPRoute
+from pyroute2.netlink.exceptions import NetlinkError, SkipInode
+from pyroute2.netlink.rtnl import RTM_DELNETNS, RTM_NEWNETNS
 from pyroute2.netlink.rtnl.nsinfmsg import nsinfmsg
-from pyroute2.netlink.exceptions import NetlinkError
-from pyroute2.netlink.exceptions import SkipInode
 
 
 class NetNSManager(Inotify):
-
     def __init__(self, libc=None, path=None, target='netns_manager'):
         path = set(path or [])
         super(NetNSManager, self).__init__(libc, path)
@@ -72,15 +70,15 @@ class NetNSManager(Inotify):
         info['header']['target'] = self.target
         info['event'] = 'RTM_NEWNETNS'
         del info['value']
-        return info,
+        return (info,)
 
     def remove(self, path):
         netnspath = netns._get_netnspath(path)
         info = None
         try:
             info = self.ipr._dump_one_ns(netnspath, set())
-        except SkipInode:
-            raise NetlinkError(errno.EEXIST)
+        except SkipInode as e:
+            raise NetlinkError(e.code)
         info['header']['type'] = RTM_DELNETNS
         info['header']['target'] = self.target
         info['event'] = 'RTM_DELNETNS'
@@ -89,7 +87,7 @@ class NetNSManager(Inotify):
             netns.remove(netnspath, self.libc)
         except OSError as e:
             raise NetlinkError(e.errno)
-        return info,
+        return (info,)
 
     def netns(self, cmd, *argv, **kwarg):
         path = kwarg.get('path', kwarg.get('NSINFO_PATH'))
@@ -104,8 +102,8 @@ class NetNSManager(Inotify):
             raise ValueError('method not supported')
         for item in self.dump():
             if item.get_attr('NSINFO_PATH') == netnspath:
-                return (item, )
+                return (item,)
         return ()
 
-    def dump(self):
+    def dump(self, groups=None):
         return self.ipr.get_netns_info()
